@@ -1,8 +1,9 @@
-from ..C_M import CM; C = CM()
+from ..ANSI_COLORS import ANSI; C = ANSI()
+from ..MODULES import IMPORT; M = IMPORT()
 from ..Logger import logger
 
 
-# ————— PORT SCAN —————
+# ————— 𝐏𝐎𝐑𝐓 𝐒𝐂𝐀𝐍 —————
 def PORT_SCAN(HOST):
 
     print(f"\n{C.X}{C.C} Scanning {C.G}{HOST} {C.C}for open ports from 1 to 65535...\n")
@@ -18,29 +19,29 @@ def PORT_SCAN(HOST):
         nonlocal Respond_PORT
 
         try:
-            sock = C.socket.socket(C.socket.AF_INET, C.socket.SOCK_STREAM)
+            sock = M.socket.socket(M.socket.AF_INET, M.socket.SOCK_STREAM)
             sock.settimeout(1)
 
             if sock.connect_ex((HOST, PORT)) == 0:
                 Respond_PORT += 1
-                C.sys.stdout.write(f"\r{' ' * 100}\r{C.S}{C.C} Port {C.E} {C.G}{PORT} ✔\n")
+                M.sys.stdout.write(f"\r{' ' * 100}\r{C.S}{C.C} Port {C.E} {C.G}{PORT} ✔\n")
 
             sock.close()
 
         except Exception as e:
-            exit(f"\n{C.RD} {e} ✘\n")
+            exit(f"\n{C.R} {e} ✘\n")
 
     for PORT in range(1, Total_PORT + 1):
-        thread = C.threading.Thread(target=check_port, args=(PORT,))
+        thread = M.threading.Thread(target=check_port, args=(PORT,))
         thread.start()
         threads.append(thread)
 
         Scanned_PORT = PORT - 1 + 1
 
         progress_line = (
-            f"{C.R}PC - {C.P}{(Scanned_PORT / Total_PORT) * 100:.2f}% {C.R}"
-            f"- Port - {C.P}{Scanned_PORT}/{C.Y}{Total_PORT} {C.R}"
-            f"- RS - {C.G}{Respond_PORT} ✔"
+            f"- PC - {(Scanned_PORT / Total_PORT) * 100:.2f}% "
+            f"- Port - {Scanned_PORT}/{Total_PORT} "
+            f"- RS - {Respond_PORT} ✔"
         )
 
         logger(progress_line)
@@ -48,4 +49,4 @@ def PORT_SCAN(HOST):
     for thread in threads:
         thread.join()
 
-    exit(f"\n\n{C.X}{C.C} Scan Complete, Total Open Ports: {C.G}{Respond_PORT} ✔\n")
\ No newline at end of file
+    exit(f"\n\n{C.X}{C.C} Scan Complete, Total Open Ports: {C.PN}{Respond_PORT} {C.G}✔\n")
\ No newline at end of file
