@@ -1,7 +1,8 @@
-from ..C_M import CM; C = CM()
+from ..ANSI_COLORS import ANSI; C = ANSI()
+from ..MODULES import IMPORT; M = IMPORT()
 
 
-# ————— Split TXT —————
+# ————— 𝐒𝐩𝐥𝐢𝐭 𝐓𝐗𝐓 —————
 def Split_TXT(TXT_FILE):
 
     try:
@@ -14,21 +15,25 @@ def Split_TXT(TXT_FILE):
 
         INPUT = int(input(f"\n{C.S}{C.P} INPUT {C.E}{C.C} Split the file in equal parts, How many parts do you want to split the file into? : {C.Y}"))
 
+        print()
         size = len(lines) // INPUT + (1 if len(lines) % INPUT else 0)
 
         base = TXT_FILE.rsplit('.', 1)[0]
 
         for index in range(0, len(lines), size):
 
-            OUTPUT = C.os.path.join(C.os.path.dirname(TXT_FILE), f"{C.os.path.basename(base)}_{index//size + 1}.txt")
+            OUTPUT = M.os.path.join(M.os.path.dirname(TXT_FILE), f"{M.os.path.basename(base)}_{index//size + 1}.txt")
 
             Wrote_Lines = lines[index:index + size]
 
-            print(f"\n{C.X} {C.C} Wrote {C.PN}{len(Wrote_Lines)} {C.C}lines to {C.Y}{OUTPUT} {C.G}✔\n")
-
             with open(OUTPUT, 'w', encoding='utf-8') as f:
                 f.write('\n'.join(Wrote_Lines))
 
+                exit(
+                    f"\n{C.S}{C.C} Wrote {C.E} {C.OG}︻デ═一 {C.PN}{len(Wrote_Lines)}\n"
+                    f"{C.P}    |\n    ╰{C.CC} OUTPUT ┈{C.OG}➢ {C.Y}{OUTPUT} {C.G}✔\n"
+                )
+
         exit(0)
 
     except FileNotFoundError:
