@@ -1,18 +1,19 @@
-from ..C_M import CM; C = CM()
+from ..ANSI_COLORS import ANSI; C = ANSI()
+from ..MODULES import IMPORT; M = IMPORT()
 
 
-# ————— CHECK TLS —————
+# ————— 𝐂𝐇𝐄𝐂𝐊 𝐓𝐋𝐒 —————
 def CHECK_TLS(HOST):
-    
+
     print(f"\n{C.X}{C.C} Check TLS Connection {C.G}{HOST}\n"
          f"\n{C.INFO} {C.C} Need Internet Connection...\n")
 
     PORT=443
 
     try:
-        sock = C.socket.create_connection((HOST, PORT))
+        sock = M.socket.create_connection((HOST, PORT))
 
-        context = C.ssl.create_default_context()
+        context = M.ssl.create_default_context()
 
         ssl_sock = context.wrap_socket(sock, server_hostname=HOST)
 
@@ -20,11 +21,11 @@ def CHECK_TLS(HOST):
 
         Cipher = ssl_sock.cipher()
 
+        ssl_sock.close()
+
         exit(f"\n{C.X}{C.C} Established Connection: {C.G}{HOST}:{PORT}\n\n"
             f"\n{C.X}{C.C} Cipher: {C.G}{Cipher[0]}\n\n"
             f"\n{C.X}{C.C} Protocol: {C.G}{TLS_Version}\n")
 
-        ssl_sock.close()
-
     except Exception as e:
         exit(f"\n{C.ERROR} {e} ✘\n")
\ No newline at end of file
